@@ -9,12 +9,17 @@
 #define ORG_H
 
 #include "kcontacts_export.h"
+
 #include <QMap>
 #include <QSharedDataPointer>
 #include <QString>
 
+class OrgTest;
+
 namespace KContacts
 {
+class ParameterMap;
+
 /** @short Class that holds a Organization for a contact.
  *  @since 5.3
  */
@@ -22,6 +27,8 @@ class KCONTACTS_EXPORT Org
 {
     friend KCONTACTS_EXPORT QDataStream &operator<<(QDataStream &, const Org &);
     friend KCONTACTS_EXPORT QDataStream &operator>>(QDataStream &, Org &);
+    friend class VCardTool;
+    friend class ::OrgTest;
 
 public:
     Org();
@@ -30,16 +37,13 @@ public:
 
     ~Org();
 
-    typedef QVector<Org> List;
+    typedef QList<Org> List;
 
     void setOrganization(const QString &org);
     Q_REQUIRED_RESULT QString organization() const;
 
     Q_REQUIRED_RESULT bool isValid() const;
 
-    void setParameters(const QMap<QString, QStringList> &params);
-    Q_REQUIRED_RESULT QMap<QString, QStringList> parameters() const;
-
     Q_REQUIRED_RESULT bool operator==(const Org &other) const;
     Q_REQUIRED_RESULT bool operator!=(const Org &other) const;
 
@@ -48,6 +52,10 @@ public:
     Q_REQUIRED_RESULT QString toString() const;
 
 private:
+    // exported for OrgTest
+    void setParams(const ParameterMap &params);
+    Q_REQUIRED_RESULT ParameterMap params() const;
+
     class Private;
     QSharedDataPointer<Private> d;
 };
@@ -55,5 +63,5 @@ KCONTACTS_EXPORT QDataStream &operator<<(QDataStream &stream, const Org &object)
 
 KCONTACTS_EXPORT QDataStream &operator>>(QDataStream &stream, Org &object);
 }
-Q_DECLARE_TYPEINFO(KContacts::Org, Q_MOVABLE_TYPE);
+Q_DECLARE_TYPEINFO(KContacts::Org, Q_RELOCATABLE_TYPE);
 #endif // ORG_H
